module Config.Pages.Products.Records.NutriDex exposing (..)

import Element exposing (..)
import Element.Font as F exposing (..)
import Config.Pages.Products.Types exposing (..)


productNutriDex : NutriDex
productNutriDex =
    { nutriDexTitle = "The NutriDex"
    , nutriDexFeatures =
        [ { feature = "The essential nutrient yields of over 700 foods are ranked and adjusted for bioavailability, nutrient absorption capacity, and metabolic conversion inefficiencies!"
          , featureTitle = "Nutrient Density Scoring: "
          }
        , { feature = "Specialized Nutrition Scoring: " ++ "Figure out the right foods for you with 30 different nutrition scores that stratify foods by a number of different dietary goals!"
          , featureTitle = "Specialized Nutrition Scoring: "
          }
        , { feature = "Use the included Custom Score tab to help create your own personal nutrition score to plan your own ideal diet!"
          , featureTitle = "Custom Nutrition Scoring: "
          }
        , { feature = "Custom-tailor your diet with in-depth nutrition data, including oxalates, phytates, glycemic index, glycemic load, satiety, FODMAPs, PCDAAS, price, shelf life, and over 500 polyphenolic compounds!"
          , featureTitle = "Diverse Nutrition Data: "
          }
        , { feature = "Avoid potential hazards from certain nutrients and other compounds with the included hazard profile data!"
          , featureTitle = "Hazard Profiles: "
          }
        , { feature = "Use the included vegan-friendly categorization to help you navigate through the best vegan options!"
          , featureTitle = "Vegan-Friendly Categorization: "
          }
        , { feature = "Use the included keto-friendly categorization to help you navigate through the best keto options!"
          , featureTitle = "Keto-Friendly Categorization: "
          }
        , { feature = "Keep expenses in check with an interactive grocery list that can intelligently estimate the cost of your grocery trip. "
          , featureTitle = "Grocery List: "
          }
        , { feature = "Use the included nutrition analyser to quantify the nutrient content of your food selection, and minimize anti-nutrients, hunger, calories, sugar, and more!"
          , featureTitle = "Nutrition Analyser: "
          }
        , { feature = "Schedule your meals and workouts, as well as calculate your calorie and macro requirements based on your goals and body composition!"
          , featureTitle = "Meal Schedule: "
          }
        ]
    , nutriDexReference =
        let
            instituteOfMedicinePub =
                "Standing Committee on the Scientific Evaluation of Dietary Reference Intakes and its Panel on Folate, Other B Vitamins, and Choline. "

            instituteOfMedicineTitle =
                "Institute of Medicine. "

            nationalAcademiesPress =
                "National Academies Press. "
        in
        [ { author = instituteOfMedicineTitle
          , year = "1998"
          , title = instituteOfMedicinePub ++ "Thiamine. "
          , journal = nationalAcademiesPress
          , link = "https://www.ncbi.nlm.nih.gov/books/NBK114331/"
          }
        , { author = instituteOfMedicineTitle
          , year = "1998"
          , title = instituteOfMedicinePub ++ "Riboflavin. "
          , journal = nationalAcademiesPress
          , link = "https://www.ncbi.nlm.nih.gov/books/NBK114322/"
          }
        , { author = instituteOfMedicineTitle
          , year = "1998"
          , title = instituteOfMedicinePub ++ "Niacin. "
          , journal = nationalAcademiesPress
          , link = "https://www.ncbi.nlm.nih.gov/books/NBK114304/"
          }
        , { author = instituteOfMedicineTitle
          , year = "2011"
          , title = "Dietary Reference Intakes for Calcium and Vitamin D. National Academies Press. "
          , journal = nationalAcademiesPress
          , link = "https://www.ncbi.nlm.nih.gov/books/NBK56056/"
          }
        , { author = instituteOfMedicineTitle
          , year = "2006"
          , title = "Dietary Reference Intakes: The Essential Guide to Nutrient Requirements. "
          , journal = "Manganese. Chapter 39, page 352. "
          , link = "https://www.nap.edu/read/11537/chapter/39"
          }
        , { author = instituteOfMedicineTitle
          , year = "2006"
          , title = "Dietary Reference Intakes: The Essential Guide to Nutrient Requirements. "
          , journal = "Phosphorus. Chapter 41, page 364. "
          , link = "https://www.nap.edu/read/11537/chapter/41"
          }
        , { author = instituteOfMedicineTitle
          , year = "2006"
          , title = "Dietary Reference Intakes: The Essential Guide to Nutrient Requirements. "
          , journal = "Potassium. Chapter 41, page 372. "
          , link = "https://www.nap.edu/read/11537/chapter/42"
          }
        , { author = instituteOfMedicineTitle
          , year = "1998"
          , title = instituteOfMedicinePub ++ "Panthotheic Acid. "
          , journal = nationalAcademiesPress
          , link = "https://www.ncbi.nlm.nih.gov/books/NBK114311/"
          }
        , { author = "Reynolds RD. "
          , year = "September 1988"
          , title = "Bioavailability of vitamin B-6 from plant foods. "
          , journal = "Am J Clin Nutr. "
          , link = "https://www.ncbi.nlm.nih.gov/pubmed/2843032"
          }
        , { author = "Shibata, Keiko, Yasuyo Yasuhara, and Kazuto Yasuda"
          , year = "2001"
          , title = "Effects of Cooking Methods on the Retention of Vitamin B6 in Foods, and the Approximate Cooking Loss in Daily Meals. "
          , journal = "J. Home Econ. Jpn. "
          , link = "https://www.semanticscholar.org/paper/Effects-of-Cooking-Methods-on-the-Retention-of-B6-Shibata-Yasuhara/b8445e60d87753144ef856e0ae207b551aa75b9c"
          }
        , { author = "Carmel, R. "
          , year = "2008"
          , title = "How I treat cobalamin (vitamin B12) deficiency. "
          , journal = "Blood"
          , link = "https://www.ncbi.nlm.nih.gov/pubmed/18606874"
          }
        , { author = "Ohrvik, Veronica E. and Cornelia M. Witthoft"
          , year = "2011"
          , title = "Human Folate Bioavailability. "
          , journal = "Nutrients"
          , link = "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3257685/"
          }
        , { author = "Novotny, Janet A., et al. "
          , year = "2010"
          , title = "β-Carotene Conversion to Vitamin A Decreases As the Dietary Dose Increases in Humans. "
          , journal = "J Nutr. "
          , link = "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC2855261/"
          }
        , { author = "Gijsbers, B.L., Jie, K.S., and Vermeer, C. "
          , year = "1996"
          , title = "Effect of food composition on vitamin K absorption in human volunteers. "
          , journal = "Br J Nutr. "
          , link = "https://www.ncbi.nlm.nih.gov/pubmed/8813897"
          }
        , { author = "Jacob, R.A., and Sotoudeh, G. "
          , year = "2002"
          , title = "Vitamin C function and status in chronic disease. "
          , journal = "Nutr Clin Care. "
          , link = "https://www.ncbi.nlm.nih.gov/pubmed/12134712"
          }
        , { author = "Reboul, Emmanuelle"
          , year = "2017"
          , title = "Vitamin E Bioavailability: Mechanisms of Intestinal Absorption in the Spotlight. "
          , journal = "Antioxidants (Basel). "
          , link = "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC5745505/"
          }
        , { author = "Zhang, Zhiying, et al. "
          , year = "2018"
          , title = "Dietary Intakes of EPA and DHA Omega-3 Fatty Acids among US Childbearing-Age and Pregnant Women: An Analysis of NHANES 2001–2014. "
          , journal = "Nutrients. "
          , link = "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC5946201/"
          }
        , { author = "Sioen, Isabelle, et al. "
          , year = "2017"
          , title = "Systematic Review on N-3 and N-6 Polyunsaturated Fatty Acid Intake in European Countries in Light of the Current Recommendations – Focus on Specific Population Groups. "
          , journal = "Ann Nutr Metab. "
          , link = "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC5452278/"
          }
        , { author = "Burdge, G.C., and Wootton, S.A. "
          , year = "2002"
          , title = "Conversion of alpha-linolenic acid to eicosapentaenoic, docosapentaenoic and docosahexaenoic acids in young women. "
          , journal = "Br J Nutr. "
          , link = "https://www.ncbi.nlm.nih.gov/pubmed/12323090"
          }
        , { author = "Rett, Brian S., and Whelan, Jay"
          , year = "2011"
          , title = "Increasing dietary linoleic acid does not increase tissue arachidonic acid content in adults consuming Western-type diets: a systematic review. "
          , journal = "Nutr Metab (Lond). "
          , link = "https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3132704/"
          }
        , { author = "Lönnerdal, B. "
          , year = "1996"
          , title = "Bioavailability of copper. "
          , journal = "Am J Clin Nutr. "
          , link = "https://www.ncbi.nlm.nih.gov/pubmed/8615369"
          }
        , { author = "Fine, K.D., et al. "
          , year = "1991"
          , title = "Intestinal absorption of magnesium from food and supplements. "
          , journal = "J Clin Invest. "
          , link = "https://www.ncbi.nlm.nih.gov/pubmed/1864954"
          }
        , { author = "Fairweather-Tait, S.J., Collings, R., and Hurst, R. "
          , year = "2010"
          , title = "Selenium bioavailability: current knowledge and future research requirements. "
          , journal = "Am J Clin Nutr. "
          , link = "https://www.ncbi.nlm.nih.gov/pubmed/20200264"
          }
        , { author = "Lönnerdal, B. "
          , year = "2000"
          , title = "Dietary factors influencing zinc absorption. "
          , journal = "J Nutr. "
          , link = "https://www.ncbi.nlm.nih.gov/pubmed/10801947"
          }
        , { author = "PDCAAS Wikipedia article"
          , year = ""
          , title = "Protein Digestibility Corrected Amino Acid Score"
          , journal = ""
          , link = "https://en.wikipedia.org/wiki/Protein_Digestibility_Corrected_Amino_Acid_Score"
          }
        ]
    }
