module Pages.Services.Analysis exposing (Model, Msg, page)

import Config.Helpers.ArticleFormat exposing (..)
import Config.Helpers.CardFormat exposing (..)
import Config.Helpers.Format exposing (..)
import Config.Helpers.Response exposing (pageList, topLevelContainer)
import Config.Helpers.ToolTip exposing (..)
import Config.Pages.Headers.Types exposing (..)
import Config.Pages.Services.Records.DebateAnalysis exposing (..)
import Config.Style.Colour exposing (colourTheme)
import Config.Style.Transitions
    exposing
        ( hoverFontDarkOrange
        , transitionStyleFast
        , transitionStyleSlow
        )
import Effect exposing (Effect)
import Element as E exposing (..)
import Element.Background as B
import Element.Border as D
import Element.Font as F
import Html
import Html.Attributes as H exposing (style)
import Layouts
import Page exposing (Page)
import Route exposing (Route)
import Route.Path as Path
import Shared
import View exposing (View)


page : Shared.Model -> Route () -> Page Model Msg
page shared route =
    Page.new
        { init = init
        , update = update
        , subscriptions = subscriptions
        , view = view shared
        }
        |> Page.withLayout toLayout


toLayout : Model -> Layouts.Layout Msg
toLayout model =
    Layouts.Navbar {}



-- INIT


type alias Model =
    {}


init : () -> ( Model, Effect Msg )
init () =
    ( {}
    , Effect.none
    )



-- UPDATE


type Msg
    = NoOp


update : Msg -> Model -> ( Model, Effect Msg )
update msg model =
    case msg of
        NoOp ->
            ( model
            , Effect.none
            )



-- SUBSCRIPTIONS


subscriptions : Model -> Sub Msg
subscriptions model =
    Sub.none



-- VIEW


view : Shared.Model -> Model -> View Msg
view shared model =
    { title = "services (analysis)"
    , attributes = []
    , element = analysisContainer shared.device
    }


analysisContainer : Device -> Element msg
analysisContainer device =
    topLevelContainer (analysisList device)


analysisList : Device -> Element msg
analysisList device =
    column pageList <|
        List.concat
            (case ( device.class, device.orientation ) of
                _ ->
                    [ [ serviceMaker ] ]
            )


serviceMaker : Element msg
serviceMaker =
    row
        topLevelBox
        [ cardMaker
            [ cardTitleMaker (String.toUpper servicesDebateAnalysis.serviceName)
            , cardFormatter
                [ cardContentSpacing
                    [ column
                        fieldSpacer
                        [ cardSubTitleMaker
                            [ column
                                bodyFormat
                                [ chunkMaker servicesDebateAnalysis.serviceArticle.articleParagraph.paragraph1
                                , chunkMaker
                                    servicesDebateAnalysis.serviceArticle.articleParagraph.paragraph2
                                , titleMaker servicesDebateAnalysis.serviceArticle.articleTitles.title1

                                -- , highlightedBlockMaker
                                , numberMaker servicesDebateAnalysis.serviceArticle.articleListEntries.list1
                                , titleMaker servicesDebateAnalysis.serviceArticle.articleTitles.title2
                                , bulletPointMaker servicesDebateAnalysis.serviceArticle.articleListEntries.list2
                                ]
                            ]
                        ]
                    ]
                ]
            ]
        ]
